@@ -360,7 +360,7 @@ class WEngine:
         :param wdb_id: ID искомых данных.
         :return:
         """
-        self.qdw.get_wserver_id(table_name, wdb_id)
+        return self.qdw.get_wserver_id(table_name, wdb_id)
         
     def start_round(self, car_number, course, car_choose_mode,
                     spec_protocol_dlinnomer_bool=False,
